@@ -27,10 +27,9 @@
  * @see KDialog::KDialog
  */
 ExportAllViewsDialog::ExportAllViewsDialog(QWidget* parent, const char* name)
-  : KDialog(parent)
+  : SinglePageDialogBase(parent)
 {
     setObjectName(QString::fromLatin1(name));
-    setModal(false);
     setupUi(mainWidget());
 
     // create and initialize m_imageType
