@@ -44,7 +44,7 @@
  *  @param  parent  The parent to the AssociationGeneralPage.
  *  @param  assoc   The AssociationWidget to display the properties of.
  */
-AssociationGeneralPage::AssociationGeneralPage (UMLDoc *d, QWidget *parent, AssociationWidget *assoc)
+AssociationGeneralPage::AssociationGeneralPage (QWidget *parent, AssociationWidget *assoc)
   : DialogPageBase(parent),
     m_pAssocNameL(0),
     m_pAssocNameLE(0),
@@ -52,7 +52,6 @@ AssociationGeneralPage::AssociationGeneralPage (UMLDoc *d, QWidget *parent, Asso
     m_pStereoChkB(0),
     m_pTypeCB(0),
     m_pAssociationWidget(assoc),
-    m_pUmldoc(d),
     m_pWidget(0)
 {
     constructWidget();
@@ -213,7 +212,7 @@ void AssociationGeneralPage::slotStereoCheckboxChanged(int state)
  *  Will move information from the dialog into the object.
  *  Call when the ok or apply button is pressed.
  */
-void AssociationGeneralPage::updateObject()
+void AssociationGeneralPage::apply()
 {
     if (m_pAssociationWidget) {
         int comboBoxItem = m_pTypeCB->currentIndex();
