@@ -31,7 +31,7 @@ class GeneralOptionPage : public DialogPageBase
 {
     Q_OBJECT
 public:
-    explicit GeneralOptionPage(QWidget* parent);
+    explicit GeneralOptionPage(QWidget* parent = 0);
     virtual ~GeneralOptionPage();
 
     void setDefaults();
