@@ -13,12 +13,13 @@
 
 #include "attribute.h"
 
-#include <kdialog.h>
+#include "singlepagedialogbase.h"
 #include <klineedit.h>
 #include <kcombobox.h>
-#include <ktextedit.h>
 
+class DocumentationWidget;
 class UMLDoc;
+class UMLStereotypeWidget;
 class QGroupBox;
 class QLabel;
 class QRadioButton;
@@ -32,7 +33,7 @@ class QRadioButton;
  * @author Paul Hensgen <phensgen@techie.com>
  * Bugs and comments to umbrello-devel@kde.org or http://bugs.kde.org
  */
-class ParameterPropertiesDialog : public KDialog
+class ParameterPropertiesDialog : public SinglePageDialogBase
 {
     Q_OBJECT
 public:
@@ -40,20 +41,9 @@ public:
     ParameterPropertiesDialog(QWidget * parent, UMLDoc * doc, UMLAttribute * attr);
     ~ParameterPropertiesDialog();
 
-public slots:
-
-    void slotOk();
+    virtual bool apply();
 
 protected:
-
-    /**
-     * Returns the documentation.
-     * @return  Returns the documentation.
-     */
-    QString getDoc() {
-        return m_doc->toPlainText();
-    }
-
     QString getName() {
         return m_pNameLE->text();
     }
@@ -70,8 +60,6 @@ protected:
 
     void insertTypesSorted(const QString& type = QString());
 
-    void insertStereotypesSorted(const QString& type = QString());
-
     bool validate();
 
 protected slots:
@@ -79,15 +67,16 @@ protected slots:
     virtual void slotButtonClicked(int button);
 
 private:
-    QGroupBox * m_pParmGB, * m_docGB;
+    QGroupBox * m_pParmGB;
     QGroupBox *m_pKind;
     QRadioButton * m_pIn, * m_pOut, *m_pInOut;
-    QLabel * m_pTypeL, * m_pNameL, * m_pInitialL, * m_pStereoTypeL;
-    KComboBox * m_pTypeCB, * m_pStereoTypeCB;
+    QLabel * m_pTypeL, * m_pNameL, * m_pInitialL;
+    KComboBox * m_pTypeCB;
     KLineEdit * m_pNameLE, * m_pInitialLE;
-    KTextEdit * m_doc;
+    DocumentationWidget * m_docWidget;
     UMLDoc * m_pUmldoc;
     UMLAttribute * m_pAtt;
+    UMLStereotypeWidget *m_stereotypeWidget;
 };
 
 #endif
