@@ -18,6 +18,7 @@
 #include <QDomDocument>
 #include <QDomElement>
 #include <QObject>
+#include <QPointer>
 #include <QString>
 
 class UMLStereotype;
@@ -110,7 +111,7 @@ public:
     QString stereotype(bool includeAdornments = false) const;
 
     void setUMLStereotype(UMLStereotype *stereo);
-    const UMLStereotype * umlStereotype();
+    UMLStereotype *umlStereotype();
 
     void setPackage(const QString &_name);
     QString package(const QString& separator = QString(),
@@ -179,7 +180,7 @@ protected:
     bool                   m_bStatic;      ///< flag for instance scope
     bool                   m_bInPaste;     ///< caller sets this true when in paste operation
     bool        m_bCreationWasSignalled;   ///< auxiliary to maybeSignalObjectCreated()
-    UMLObject*             m_pSecondary;   ///< pointer to an associated object
+    QPointer<UMLObject>    m_pSecondary;   ///< pointer to an associated object
                                            ///< Only a few of the classes inheriting from UMLObject use this.
                                            ///< However, it needs to be here because of inheritance graph
                                            ///< disjunctness.
